// swift-tools-version:5.5
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "{{ package_name }}",
    platforms: [
        .iOS(.v13),
    ],
    products: [
        .library(
            name: "{{ package_name }}",
            targets: ["{{ package_name }}"]
        ),
    ],
    dependencies: [
        // Centrifugo WebSocket client (official)
        .package(url: "https://github.com/centrifugal/centrifuge-swift.git", from: "0.6.0"),
    ],
    targets: [
        .target(
            name: "{{ package_name }}",
            dependencies: [
                .product(name: "SwiftCentrifuge", package: "centrifuge-swift"),
            ],
            path: "Sources/{{ package_name }}"
        ),
    ]
)
