export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',
  'test-runners': 'Test Runners',
  'test-db-command': 'test_db Command',
  'migration-internals': 'Migration Internals',
}
