# Auto-generated by DjangoCFG - see CLAUDE.md

from __future__ import annotations
from typing import Any

from pydantic import BaseModel, ConfigDict, Field


class ConnectionTokenResponse(BaseModel):
    """
    Response model for Centrifugo connection token.

    Response model (includes read-only fields).
    """

    model_config = ConfigDict(
        validate_assignment=True,
        extra="allow",
        frozen=False,
    )

    token: str = Field(description='JWT token for Centrifugo connection')
    centrifugo_url: str = Field(description='Centrifugo WebSocket URL')
    expires_at: str = Field(description='Token expiration time (ISO 8601)')
    channels: list[str] = Field(description='List of allowed channels')



