export default {
  'index': { display: 'hidden' },
  'architecture': 'Module Architecture',
  'pydantic-models': 'Pydantic v2 Models',
  'type-checking': 'Type Checking',
  'async-patterns': 'Async & Concurrency',
  'error-handling': 'Error Handling',
  'testing': 'Testing',
  'dependency-injection': 'Dependency Injection',
  'resilience': 'Resilience Patterns',
  'code-style': 'Code Style',
  'performance': 'Performance',
  'refactoring': 'Refactoring Checklist',
  'quick-reference': 'Quick Reference',
}
