export default {
  'index': { display: 'hidden' },
  'zustand': 'Zustand',
  'forms': 'Forms',
  'i18n': 'Internationalization',
  'dnd': 'Drag & Drop',
  'animations': 'Animations',
  'ui-components': 'UI Components',
  'tailwind-v4': 'Tailwind v4',
  'extensions': 'Extensions',
}
