export default {
  'index': 'Overview',
  'setup': 'Setup',
  'architecture': 'Architecture',
  'backend-guide': 'Backend Guide',
  'frontend-guide': 'Frontend Guide',
  'client-generation': 'Client Generation',
  'cli-commands': 'CLI Commands',
  'api-reference': 'API Reference'
}
