{% include '_header.jinja' %}

from enum import Enum{% if has_int_enum %}, IntEnum{% endif %}



class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


{% for enum in enums %}
{{ enum }}


{% endfor %}
