export default {
  'overview': 'Overview',
  'quick-start': 'Quick Start',
  'configuration': 'Configuration',
  'extensions': 'Extensions',
  'authentication': 'Authentication',
  'api-integration': 'API Integration',
  'theming': 'Theming',
  'deployment': 'Deployment',
}
