export default {
  'index': 'Overview',
  'django-integration': 'Django Integration',
  'registry': 'Registry',
  'routing': 'Routing',
  'middleware': 'Middleware',
  'cors': 'CORS',
  'rate-limiting': 'Rate Limiting',
  'startup': 'Startup',
  'utilities': 'Utilities'
}
