# Generated by Django 5.2.6 on 2025-09-20 16:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_cfg_accounts', '0005_twilioresponse'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='twilioresponse',
            name='otp_secret',
        ),
        migrations.RemoveIndex(
            model_name='otpsecret',
            name='django_cfg__recipie_f9f5aa_idx',
        ),
        migrations.RemoveField(
            model_name='customuser',
            name='phone_verified',
        ),
        migrations.RemoveField(
            model_name='otpsecret',
            name='channel_type',
        ),
        migrations.RemoveField(
            model_name='otpsecret',
            name='recipient',
        ),
        migrations.AddField(
            model_name='otpsecret',
            name='email',
            field=models.EmailField(db_index=True, default=1, max_length=254),
            preserve_default=False,
        ),
        migrations.AddIndex(
            model_name='otpsecret',
            index=models.Index(fields=['email', 'is_used', 'expires_at'], name='django_cfg__email_f595c8_idx'),
        ),
        migrations.DeleteModel(
            name='TwilioResponse',
        ),
    ]
