export default {
  'overview': 'Overview',
  'configuration': 'Configuration',
  'server-capture': 'Server-Side Capture',
  'frontend-sdk': 'Frontend SDK',
  'layouts-integration': '@djangocfg/layouts',
  'management-commands': 'Management Commands',
}
