# Generated by Django 5.2.6 on 2025-09-16 18:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_cfg_accounts', '0003_twilioresponse'),
    ]

    operations = [
        migrations.DeleteModel(
            name='TwilioResponse',
        ),
    ]
