# Compatibility shim — DocumentationConfig/DocumentationSection moved to documentation/ subpackage.
from .documentation import DocumentationConfig, DocumentationSection

__all__ = ["DocumentationConfig", "DocumentationSection"]
