export default {
  'index': 'Overview',
  'url-configuration': 'URL Configuration',
  'multi-database': 'Multi-Database',
  'routing': 'Routing',
  'migrations': 'Migrations',
  'cross-database-relations': 'Cross-Database Relations'
}
