from ._base import OGImagePreset

DARK = OGImagePreset(
    name="dark",
    bg_color="#1a1a2e",
    bg_color2="#16213e",
    text_color="#ffffff",
    accent_color="#3b82f6",
    style="dark",
)

DARK_BLUE = OGImagePreset(
    name="dark_blue",
    bg_color="#0f172a",
    bg_color2="#1e3a5f",
    text_color="#f1f5f9",
    accent_color="#38bdf8",
    style="dark",
)

DARK_PURPLE = OGImagePreset(
    name="dark_purple",
    bg_color="#1e1b4b",
    bg_color2="#312e81",
    text_color="#ede9fe",
    accent_color="#a78bfa",
    style="dark",
)

DARK_GREEN = OGImagePreset(
    name="dark_green",
    bg_color="#052e16",
    bg_color2="#14532d",
    text_color="#dcfce7",
    accent_color="#4ade80",
    style="dark",
)

DARK_ROSE = OGImagePreset(
    name="dark_rose",
    bg_color="#1c0a15",
    bg_color2="#4c0519",
    text_color="#ffe4e6",
    accent_color="#fb7185",
    style="dark",
)
