export default {
  'overview': 'Overview',
  'getting-started': 'Getting Started',
  'cli-commands': 'CLI Commands',
  'advanced': 'Advanced',
  'examples': 'Examples',
  'troubleshooting': 'Troubleshooting'
}
