"""
Generated Pydantic Models.

Auto-generated from RPC handler type hints - DO NOT EDIT
"""

from typing import Optional, List, Dict, Any, Union
from pydantic import BaseModel, Field


{% for model in models %}
{{ model.code }}


{% endfor %}

__all__ = [
{% for model in models %}    "{{ model.name }}",
{% endfor %}]
